pub fn kraken_http_should_retry(error: &KrakenHttpError) -> boolExpand description
Returns true if a request producing this error should be retried.
pub fn kraken_http_should_retry(error: &KrakenHttpError) -> boolReturns true if a request producing this error should be retried.